==> fop2-2.24-debian-x86_64.tgz: fop2/html/js/lang_en.js <==

lang['incoming_call']      = 'Incoming call';
lang['connecting_server']  = 'Connecting to server, attempt number ';

lang['from_queue']         = "From queue:";
lang['number']             = "Number:";
lang['name']               = "Name:";

lang['dial']               = 'Dial';
lang['transfer_vmail']     = 'Transfer to Mailbox';
lang['transfer_external']  = 'Transfer to Mobile';
lang['attendant_transfer'] = 'Transfer';
lang['spy']                = 'Listen';
lang['whisper']            = 'Listen and Whisper';
lang['pickup']             = "Call pickup";
lang['hangup']             = 'Hangup';
lang['filter']             = 'Filter';

lang['enter_sec_code']     = 'Login details';
lang['exten']              = 'Extension:';
lang['password']           = 'Password:';

lang['confirm_hangup']     = 'Confirm Hangup';
lang['areyousure']         = 'Are you sure?';
lang['yes']                = 'Yes';
lang['no']                 = 'No';

lang['paused']             = 'Paused';
lang['set_information']    = 'Set Information';
lang['member_of']          = 'Member of ';
lang['not_available']      = 'System is not available right now';
lang['not_connect']        = 'Could not connect to server';
lang['one_moment']         = 'One moment please';
lang['no_results']         = 'No results were found';

lang['toggle_lock']        = 'Lock/Unlock Conference';
lang['toggle_muteall']     = 'Mute/Unmute all users';
lang['available']          = 'Available';
lang['phonebook']          = 'Phonebook';
lang['toggle_mute']        = 'Toggle mute';
lang['kick']               = 'Kick user';
lang['record']             = 'Record call';
lang['presence_noti']      = 'Presence Notification';

lang['queues']             = 'Queues';
lang['extensions']         = 'Extensions';
lang['trunks']             = 'Trunks';
lang['conferences']        = 'Conferences';
lang['other']              = 'Other';
lang['enter_state']        = 'Enter Value';
lang['parkingslots']       = 'Park Slots';
lang['ringgroups']         = 'Ring Groups';

lang['enter_reg_code']     = 'Enter Registration Code:';
lang['reg_code']     = 'Registration Code:';
lang['reg_name']     = 'Registration Name:';

lang['remove_member']      = 'Remove Member';
lang['remove_member_from'] = 'Remove from ';
lang['pause_member']       = 'Pause Member';
lang['unpause_member']     = 'Unpause Member';
lang['add_member']         = 'Add to ';
lang['pickup_call']        = 'Pickup Call';
lang['email_user']         = 'Send email';
lang['send_sms']           = 'Send SMS';
lang['message']            = 'Message:';
lang['sending']            = 'Sending...';
lang['noResponse']         = 'No response.';

lang['chat']               = 'Chat';
lang['notlogged']          = 'User not logged in. Saving note.';
lang['me']                 = 'Me';
lang['clearchat']          = 'Clear Chat Window';
lang['note']               = 'Note';
lang['toggle_sound']       = 'Toggle Sound';
lang['says']               = 'says';

lang['agents']             = 'Agents: %d';
lang['calls']              = 'Waiting Calls: %d';
lang['call_connected']     = 'Talking to';
lang['changeDisplayType']  = 'Change display type';

lang['voicemail']          = 'Voicemail';
lang['vmail_new']          = 'New';
lang['vmail_old']          = 'Old';
lang['vmail_work']         = 'Work';
lang['vmail_family']       = 'Family';
lang['vmail_friends']      = 'Friends';
lang['vmail_number']       = 'No.';
lang['vmail_date']         = 'Date';
lang['vmail_callerid']     = 'CallerID';
lang['vmail_duration']     = 'Duration';

lang['preferences']        = 'Preferences';
lang['summary']            = 'Summary';
lang['detailed']           = 'Detailed';

lang['inactive_line']      = 'Line %d inactive';
lang['inuse']              = '%d lines in use';
lang['vmail_count']        = 'New %d, Old %d';
lang['logout']             = 'Logout';

lang['NOTONLINE']          = 'User is offline';
lang['NOWONLINE']          = 'User is now online';

lang['prefSounds']         = 'Sounds';
lang['prefDisplay']        = 'Display';

lang['labelSoundChat']     = 'Chat Sounds';
lang['labelSoundQueue']    = 'Queue Sounds';
lang['labelSoundRing']     = 'Ring Sounds';

lang['labelDisplayQueue']          = 'Default Queue View:';
lang['labelDisplayDynamicLine']    = 'Dynamic Line Display:';
lang['labelDisplayNotifyDuration'] = 'Notify Duration:';
lang['labelDisplayLanguage']       = 'Language:';

// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
		"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat",
		"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"
	],
	monthNames: [
		"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
		"January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"
	]
};

==> fop2-2.29.03-debian-x86_64.tgz: fop2/html/js/lang_en.js <==

lang['incoming_call']      = 'Incoming call';
lang['connecting_server']  = 'Connecting to server, attempt number ';

lang['from_queue']         = "From queue:";
lang['number']             = "Number:";
lang['name']               = "Name:";

lang['dial']               = 'Dial';
lang['transfer_vmail']     = 'Transfer to Mailbox';
lang['transfer_external']  = 'Transfer to Mobile';
lang['attendant_transfer'] = 'Supervised Transfer';
lang['blind_transfer'] =     'Blind Transfer';
lang['spy']                = 'Listen';
lang['whisper']            = 'Listen and Whisper';
lang['pickup']             = "Call pickup";
lang['hangup']             = 'Hangup';
lang['filter']             = 'Filter';

lang['enter_sec_code']     = 'Login details';
lang['exten']              = 'Extension:';
lang['password']           = 'Password:';

lang['confirm_hangup']     = 'Confirm Hangup';
lang['areyousure']         = 'Are you sure?';
lang['yes']                = 'Yes';
lang['no']                 = 'No';
lang['cancel']             = 'Cancel';
lang['accept']             = 'Accept';

lang['paused']             = 'Paused';
lang['set_information']    = 'Set Information';
lang['set_penalty']        = 'Penalty';
lang['member_of']          = 'Member of ';
lang['not_available']      = 'System is not available right now';
lang['not_connect']        = 'Could not connect to server';
lang['one_moment']         = 'One moment please';
lang['no_results']         = 'No results were found';

lang['toggle_lock']        = 'Lock/Unlock Conference';
lang['toggle_muteall']     = 'Mute/Unmute all users';
lang['phonebook']          = 'Phonebook';
lang['toggle_mute']        = 'Toggle mute';
lang['kick']               = 'Kick user';
lang['record']             = 'Record call';
lang['presence_noti']      = 'Presence Notification';

lang['queues']             = 'Queues';
lang['extensions']         = 'Extensions';
lang['trunks']             = 'Trunks';
lang['conferences']        = 'Conferences';
lang['enter_state']        = 'Enter Value';
lang['parkingslots']       = 'Park Slots';
lang['ringgroups']         = 'Ring Groups';

lang['available']          = 'Available';
lang['other']              = 'Other';
lang['Do not Disturb']     = 'Do not Disturb';
lang['Out to lunch']       = 'Out to lunch';
lang['Break']              = 'Break';
lang['Meeting']            = 'Meeting';

lang['enter_reg_code']     = 'Enter Registration Code:';
lang['reg_code']     = 'Registration Code:';
lang['reg_name']     = 'Registration Name:';

lang['remove_member']      = 'Remove Member';
lang['remove_member_from'] = 'Remove from ';
lang['pause_member']       = 'Pause Member';
lang['unpause_member']     = 'Unpause Member';
lang['add_member']         = 'Add to ';
lang['pickup_call']        = 'Pickup Call';
lang['email_user']         = 'Send email';
lang['send_sms']           = 'Send SMS';
lang['message']            = 'Message:';
lang['sending']            = 'Sending...';
lang['noResponse']         = 'No response.';
lang['calls_taken']        = 'Calls taken:';
lang['penalty']            = 'Penalty:';

lang['chat']               = 'Chat';
lang['notlogged']          = 'User not logged in. Saving note.';
lang['me']                 = 'Me';
lang['clearchat']          = 'Clear Chat Window';
lang['note']               = 'Note';
lang['toggle_sound']       = 'Toggle Sound';
lang['says']               = 'says';

lang['agents']             = 'Agents: %d';
lang['calls']              = 'Waiting Calls: %d';
lang['call_connected']     = 'Talking to';
lang['changeDisplayType']  = 'Change display type';

lang['voicemail']          = 'Voicemail';
lang['vmail_new']          = 'New';
lang['vmail_old']          = 'Old';
lang['vmail_work']         = 'Work';
lang['vmail_family']       = 'Family';
lang['vmail_friends']      = 'Friends';
lang['vmail_number']       = 'No.';
lang['vmail_date']         = 'Date';
lang['vmail_callerid']     = 'CallerID';
lang['vmail_duration']     = 'Duration';
lang['play']               = 'Play';
lang['download']           = 'Download';

lang['preferences']        = 'Preferences';
lang['summary']            = 'Summary';
lang['detailed']           = 'Detailed';

lang['inactive_line']      = 'Line %d inactive';
lang['inuse']              = '%d lines in use';
lang['vmail_count']        = 'New %d, Old %d';
lang['logout']             = 'Logout';

lang['NOTONLINE']          = 'User is offline';
lang['NOWONLINE']          = 'User is now online';

lang['prefSounds']         = 'Sounds';
lang['prefDisplay']        = 'Display';
lang['prefPopup']          = 'Popup';
lang['prefPhone']          = 'Phone';

lang['labelSoundChat']     = 'Chat Sounds';
lang['labelSoundQueue']    = 'Queue Sounds';
lang['labelSoundRing']     = 'Ring Sounds';

lang['labelDisplayQueue']          = 'Default Queue View';
lang['labelDisplayDynamicLine']    = 'Dynamic Line Display';
lang['labelDisplayNotifyDuration'] = 'Notify Duration';
lang['labelDisplayLanguage']       = 'Language';
lang['labelAutoPopup']             = 'Automatic Popup';
lang['labelAutoAnswer']            = 'Auto Answer';

lang['close']                      = 'Close';
lang['recordings']                 = 'Recordings';
lang['cdrrecords']                 = 'Call History';

// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
		"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat",
		"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"
	],
	monthNames: [
		"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
		"January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"
	]
};
